HttpPaymaster class

HTTP-based paymaster that communicates with a paymaster service.

Implemented types

Constructors

HttpPaymaster({required String paymasterUrl, required String paymasterAddress, Map<String, String> headers = const {}})

Properties

address String
Gets the paymaster address.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canSponsor(UserOperation userOp) Future<bool>
Validates that the paymaster can sponsor the given UserOperation.
override
dispose() → void
Disposes of the paymaster client.
getPaymasterData(UserOperation userOp, {required String entryPointAddress, required int chainId}) Future<PaymasterData?>
Gets paymaster data for a UserOperation.
override
getPaymasterMetadata() Future<Map<String, dynamic>?>
Gets paymaster metadata such as supported tokens, policies, etc.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited